==> kano_cv-3.2.3.tar.gz: kano_cv-3.2.3/README.md <==
# 🦌 Kano - Utilities for your Computer Vision Projects

![banner image](docs/img/banner.png)

[![Kano CI](https://github.com/egliette/kano/actions/workflows/python-app.yml/badge.svg)](https://github.com/egliette/kano/actions/workflows/python-app.yml)

**Kano** is a Python package providing utility functions for Computer Vision tasks. Its primary focus is simplifying lengthy functions, allowing developers to concentrate more on the main processes.

## 📥 Installation

[The latest released version](https://pypi.org/project/kano-cv/) is available on PyPI. You can install it by running the following command in your terminal:

```bash
pip install kano-cv
```

## 🚀 Usage

Explore the [Kano Document](https://egliette.github.io/kano/) to learn how to use supported functions and see examples. **Kano** currently provides utilities for these groups:

- [Common tasks](https://egliette.github.io/kano/common/):
    - [Images Processing](https://egliette.github.io/kano/common/image_utils/)
    - [Videos Processing](https://egliette.github.io/kano/common/video_utils/)
    - [Files/Folders Manipulating](https://egliette.github.io/kano/common/file_utils/)
- [Computer vision tasks](https://egliette.github.io/kano/cv/):
    - [YOLO-formatted Dataset](https://egliette.github.io/kano/cv/dataset_utils/)
    - [Object Detection](https://egliette.github.io/kano/cv/detect_utils/)
    - Pose Estimation (In progress)
    - Object Segmentation (In progress)
    - [Profiling](https://egliette.github.io/kano/cv/profiler/)
    - [Source Reader](https://egliette.github.io/kano/cv/source_reader/)


## 🙋‍♂️ Contributing to Kano

All contributions, bug reports, bug fixes, enhancements, and ideas are welcome. Feel free to create pull requests or issues so that we can improve this library together.

## 🔑 License
Kano is licensed under the [MIT](LICENSE) license.

==> kano_cv-3.4.0.tar.gz: kano_cv-3.4.0/README.md <==
# 🦌 Kano - Utilities for your Computer Vision Projects

![banner image](docs/img/banner.png)

[![Kano CI](https://github.com/egliette/kano/actions/workflows/python-app.yml/badge.svg)](https://github.com/egliette/kano/actions/workflows/python-app.yml)

**Kano** is a Python package providing utility functions for Computer Vision tasks. Its primary focus is simplifying lengthy functions, allowing developers to concentrate more on the main processes.

## 📥 Installation

[The latest released version](https://pypi.org/project/kano-cv/) is available on PyPI. You can install it by running the following command in your terminal:

```bash
pip install kano-cv
```

## 🚀 Usage

Explore the [Kano Document](https://egliette.github.io/kano/) to learn how to use supported functions and see examples. **Kano** currently provides utilities for these groups:

- [Common tasks](https://egliette.github.io/kano/common/):
    - [Images Processing](https://egliette.github.io/kano/common/image_utils/)
    - [Videos Processing](https://egliette.github.io/kano/common/video_utils/)
    - [Files/Folders Manipulating](https://egliette.github.io/kano/common/file_utils/)
- [Computer vision tasks](https://egliette.github.io/kano/cv/):
    - [YOLO-formatted Dataset](https://egliette.github.io/kano/cv/dataset_utils/)
    - [Object Detection](https://egliette.github.io/kano/cv/detect_utils/)
    - Pose Estimation (In progress)
    - Object Segmentation (In progress)
- [Real-time camera simulation](https://egliette.github.io/kano/simulation/)
    - [FPS, Resouces Profiling](https://egliette.github.io/kano/simulation/profiler/)
    - [Real-time Camera Source Reader](https://egliette.github.io/kano/source_reader/)
    - [Real-time Fake Detection](https://egliette.github.io/kano/fake_detection/)


## 🙋‍♂️ Contributing to Kano

All contributions, bug reports, bug fixes, enhancements, and ideas are welcome. Feel free to create pull requests or issues so that we can improve this library together.

## 🔑 License
Kano is licensed under the [MIT](LICENSE) license.
